pub enum ResolutionError {
UnsortedEnergies,
LengthMismatch {
energies: usize,
data: usize,
},
}Expand description
Errors from resolution broadening operations.
Variants
UnsortedEnergies
The energy grid is not sorted in ascending order.
LengthMismatch
The energy grid and data arrays have mismatched lengths.